@@ -1,5 +1,6 @@
 import logging
 
+from django.conf import settings
 from django.contrib import messages
 from django.contrib.auth import login
 from django.core.urlresolvers import reverse
@@ -61,34 +62,40 @@ class LoginView(NeverCacheMixin, LogoutUserMixin, FormView):
         if renew:
             logger.debug("Renew request received by credential requestor")
             self.logout_user(request)
-            login = add_query_params(reverse('cas_login'),
-                                     {'service': service})
-            logger.debug("Redirecting to %s" % login)
-            return redirect(login)
+            login_url = add_query_params(reverse('cas_login'),
+                                         {'service': service})
+            logger.debug("Redirecting to %s" % login_url)
+            return redirect(login_url)
         elif gateway and service:
             logger.debug("Gateway request received by credential requestor")
             if request.user.is_authenticated():
                 if self.warn_user() and not warned:
-                    return redirect(add_query_params(reverse('cas_warn'),
-                                                     {'service': service,
-                                                      'gateway': gateway}))
+                    warn_url = add_query_params(reverse('cas_warn'),
+                                                {'service': service,
+                                                 'gateway': gateway})
+                    return redirect(warn_url)
+
                 st = ServiceTicket.objects.create_ticket(service=service,
                                                          user=request.user)
-                service = add_query_params(service, {'ticket': st.ticket})
-            logger.debug("Redirecting to %s" % service)
-            return redirect(service)
+                service_url = add_query_params(service, {'ticket': st.ticket})
+            else:
+                service_url = service
+            logger.debug("Redirecting to %s" % service_url)
+            return redirect(service_url)
         elif request.user.is_authenticated():
             if service:
                 logger.debug("Service ticket request received "
                              "by credential requestor")
                 if self.warn_user() and not warned:
-                    return redirect(add_query_params(reverse('cas_warn'),
-                                                     {'service': service}))
+                    warn_url = add_query_params(reverse('cas_warn'),
+                                                {'service': service})
+                    return redirect(warn_url)
+
                 st = ServiceTicket.objects.create_ticket(service=service,
                                                          user=request.user)
-                service = add_query_params(service, {'ticket': st.ticket})
-                logger.debug("Redirecting to %s" % service)
-                return redirect(service)
+                service_url = add_query_params(service, {'ticket': st.ticket})
+                logger.debug("Redirecting to %s" % service_url)
+                return redirect(service_url)
             else:
                 msg = _("You are logged in as %s") % request.user
                 messages.success(request, msg)
@@ -186,14 +193,18 @@ class LogoutView(NeverCacheMixin, LogoutUserMixin, View):
     ended, requiring a new single sign-on session to be established
     for future authentication attempts.
 
-    If ``url`` is specified, it will be displayed to the user as a
-    recommended link to follow.
+    If ``url`` is specified, by default it will be displayed to the
+    user as a recommended link to follow. This behavior can be altered
+    by setting ``MAMA_CAS_FOLLOW_LOGOUT_URL`` to ``True``, which will
+    redirect the client to the specified URL.
     """
     def get(self, request, *args, **kwargs):
         logger.debug("Logout request received for %s" % request.user)
         self.logout_user(request)
-        url = request.GET.get('url', None)
+        url = request.GET.get('url')
         if url and is_valid_service_url(url):
+            if getattr(settings, 'MAMA_CAS_FOLLOW_LOGOUT_URL', False):
+                return redirect(url)
             msg = _("The application provided this link to follow: %s") % url
             messages.success(request, msg)
         return redirect(reverse('cas_login'))
